<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        title="编辑"
        width="75%"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="superRef" :rules="state.formRules" label-width="150px" >
        <el-row>
          <el-col :sm="24" :md="12">
            <el-form-item label="部门名称:" prop="deptName">
              <el-input v-model.trim="state.form.deptName" readonly></el-input>
            </el-form-item>
          </el-col>
          <el-col :sm="24" :md="12">
            <el-form-item label="部门负责人:" prop="leaderName">
              <el-input v-model.trim="state.form.leaderName" readonly></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :sm="24" :md="12">
            <el-form-item label="部门人数:" prop="personNum">
              <el-input type="number" v-model.trim.number="state.form.personNum" placeholder="请输入部门人数" ></el-input>
            </el-form-item>
          </el-col>
          <el-col :sm="24" :md="12">
            <el-form-item label="内审员:" prop="internalAuditors">
              <el-select
                  clearable
                  v-model="state.form.internalAuditors"
                  filterable
                  placeholder="内审员"
                  style="width: 100%"
              >
                <el-option
                    v-for="item in state.userList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-form-item label="部门职责:" prop="responsibilities">
          <el-input
              v-model="state.form.responsibilities"
              style="width: 100%"
              :autosize="{ minRows: 2, maxRows: 4 }"
              type="textarea"
              placeholder="部门职责"
          />
        </el-form-item>
      </el-form>
      <el-button
          type="primary"
          plain
          icon="Plus"
          @click="addLine"
          style="margin-bottom: 10px"
      >新增</el-button>
      <el-table :data="state.form.sysDeptResponsibilityList" class="customedTable" :border="true">
        <el-table-column label="条款号" prop="clauseNum" align="center" width="80">
          <template #default="scope">
            <el-input
                v-model.trim="scope.row.clauseNum"
                size="large"
                type="textarea"
                style="width: 100%;"
            >
            </el-input>
          </template>
        </el-table-column>
        <el-table-column label="内容" prop="content" align="center">
          <template #default="scope">
            <el-input
                v-model.trim="scope.row.content"
                size="large"
                type="textarea"
                style="width: 100%;"
            >
            </el-input>
          </template>
        </el-table-column>
        <el-table-column label="条款负责人" prop="leader" align="center">
          <template #default="scope">
<!--            <el-select-->
<!--                v-model="scope.row.leader"-->
<!--                filterable-->
<!--                size="large"-->
<!--                style="width: 100%"-->
<!--            >-->
<!--              <el-option-->
<!--                  v-for="item in state.userList"-->
<!--                  :key="item.id"-->
<!--                  :label="item.name"-->
<!--                  :value="item.id"-->
<!--              />-->
<!--            </el-select>-->
            <el-input
                v-model.trim="scope.row.leader"
                size="large"
                type="textarea"
                style="width: 100%;"
            >
            </el-input>
          </template>
        </el-table-column>
        <el-table-column label="相关证据材料" prop="evidenceMaterials" align="center">
          <template #default="scope">
            <el-input
                v-model.trim="scope.row.evidenceMaterials"
                size="large"
                type="textarea"
                style="width: 100%;"
            >
            </el-input>
          </template>
        </el-table-column>
        <el-table-column label="现有管理类文件" prop="managementDocuments" align="center" width="150">
          <template #default="scope">
            <el-input
                v-model.trim="scope.row.managementDocuments"
                size="large"
                type="textarea"
                style="width: 100%;"
                clearable
            >
            </el-input>
          </template>
        </el-table-column>
        <el-table-column label="技术类文件" prop="technicalDocuments" align="center" width="150">
          <template #default="scope">
            <el-input
                v-model.trim="scope.row.technicalDocuments"
                type="textarea"
                size="large"
                style="width: 100%;"
            >
            </el-input>
          </template>
        </el-table-column>
        <el-table-column label="现有记录" prop="existingRecords" align="center" width="150">
          <template #default="scope">
            <el-input
                v-model.trim="scope.row.existingRecords"
                type="textarea"
                size="large"
                style="width: 100%;"
            >
            </el-input>
          </template>
        </el-table-column>
        <el-table-column label="操作" align="center" width="70">
          <template #default="scope">
<!--            <el-button link type="primary" @click="openEdit('edit',scope.row)">编辑</el-button>-->
            <el-button link type="danger" @click="handleDelete(scope.$index)">删除</el-button>
          </template>
        </el-table-column>
      </el-table>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs, defineEmits, nextTick, onMounted, computed, watch} from 'vue'
import {ElMessage} from "element-plus";
import {getDeptInfo, saveResponsibility} from "@/api/orgStructure/depart";
import {listUser} from "@/api/system/user";
const emit = defineEmits(["getList"]);
const dialogVisible = ref(false)
const superRef = ref()

const state = reactive({
  form: {
    deptName: '',
    leaderName: '',
    companyId: null,
    delData: [],
    deptId: null,
    internalAuditors: null,
    personNum: null,
    responsibilities: '',
    sysDeptResponsibilityList: []
  },
  oldResponsibilityList: [],
  formRules:{
    personNum: [{ required: true, message: '请输入部门人数', trigger: 'blur' }],
    // internalAuditors: [{ required: true, message: '请选择内审员', trigger: 'blur' }],
    responsibilities: [{ required: true, message: '请输入部门职责', trigger: 'blur' }]
  },
  userList: []
})

onMounted(() => {

});

const openDialog = async (value) => {
  await getUserList()
  await getDeptDetail(value.deptId)
  dialogVisible.value = true
}

const getDeptDetail = async (deptId)=>{
  const res = await getDeptInfo(deptId)
  if (res.code == 200) {
    if(res.data){
      Object.keys(state.form).forEach(key => {
        if (key in res.data) {
          state.form[key] = res.data[key];
        }
      })
      state.form.sysDeptResponsibilityList = res.data.sysDeptResponsibilitys
      state.oldResponsibilityList = res.data.sysDeptResponsibilitys
      state.form.personNum = state.form.personNum==0?null:state.form.personNum
      state.form.internalAuditors = state.form.internalAuditors==0?null:state.form.internalAuditors
    }else{
      ElMessage.warning('暂无部门信息')
    }
  } else {
    ElMessage.warning(res.message)
  }
}

const getUserList = async ()=> {
  const res = await listUser()
  if(res.code == 200){
    state.userList = res.data.list?res.data.list:[]
  }else{
    ElMessage.warning(res.message)
  }
}

const addLine = () => {
  const obj = {
    clauseNum: '',
    content: '',
    leader: '',
    evidenceMaterials: '',
    managementDocuments: '',
    technicalDocuments: '',
    existingRecords: ''
  }
  state.form.sysDeptResponsibilityList.push(obj);
}

const handleDelete = (i) =>{
  state.form.sysDeptResponsibilityList = state.form.sysDeptResponsibilityList.filter((item,index) => index != i)
}

const onSubmit = async () => {
  const valid = await superRef.value.validate();
  if(valid){
    state.form.delData = state.oldResponsibilityList.filter(oldItem => !state.form.sysDeptResponsibilityList.some(newItem => newItem.id === oldItem.id)).map(item => item.id)
    for(let i of state.form.sysDeptResponsibilityList){
      if(i.clauseNum == '' || i.content==''){
        ElMessage.warning('条款编号、内容不可为空')
        return
      }
    }
    const res = await saveResponsibility(state.form)
    if(res.code == 200){
      ElMessage.success(res.message)
      handleClose()
      emit('getList')
    }else{
      ElMessage.warning(res.message)
    }
  }
}

const handleClose = () => {
  state.form = {
    deptName: '',
    leaderName: '',
    companyId: null,
    delData: [],
    deptId: null,
    internalAuditors: null,
    personNum: null,
    responsibilities: '',
    sysDeptResponsibilityList: []
  }
  dialogVisible.value = false
}

defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
<style lang="scss">
  .customedTable{
    .el-table__cell{
      padding: 2px 0 !important;
      font-size: 14px !important;
    }
    .cell{
      padding: 0 2px !important;
      font-size: 14px !important;
    }
  }
</style>